LocalStorage class

Constructors

LocalStorage({required ChatwootUserDao userDao, required ChatwootConversationDao conversationDao, required ChatwootContactDao contactDao, required ChatwootMessagesDao messagesDao})

Properties

contactDao ↔ ChatwootContactDao
getter/setter pair
conversationDao ↔ ChatwootConversationDao
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messagesDao ↔ ChatwootMessagesDao
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userDao ↔ ChatwootUserDao
getter/setter pair

Methods

clear({bool clearChatwootUserStorage = true}) → Future<void>
clearAll() → Future<void>
dispose() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

openDB({void onInitializeHive()?}) → Future<void>